import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:minehunter/cubit/game_cubit.dart';
import 'package:minehunter/models/game/game.dart';

class TopIndicator extends StatelessWidget {
  const TopIndicator({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;

        final String skin = currentGame.globalSettings.skin;

        final int flaggedCellsCount = currentGame.countFlaggedCells();
        final int minesCount = currentGame.minesCount;
        const double blockSize = 40;

        final Image flagIconBlock = Image(
          image: AssetImage('assets/skins/${skin}_tile_flag.png'),
          fit: BoxFit.fill,
          height: blockSize,
          width: blockSize,
        );
        final Image mineIconBlock = Image(
          image: AssetImage('assets/skins/${skin}_tile_mine.png'),
          fit: BoxFit.fill,
          height: blockSize,
          width: blockSize,
        );
        final Text markedMinesCountBlock = Text(
          flaggedCellsCount.toString(),
          style: TextStyle(
            fontSize: blockSize,
            fontWeight: FontWeight.bold,
            color: Theme.of(context).colorScheme.primary,
          ),
        );
        final Text placedMinesCountBlock = Text(
          minesCount.toString(),
          style: TextStyle(
            fontSize: blockSize,
            fontWeight: FontWeight.bold,
            color: Theme.of(context).colorScheme.primary,
          ),
        );

        return Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                markedMinesCountBlock,
                flagIconBlock,
                const SizedBox(width: blockSize * 2),
                mineIconBlock,
                placedMinesCountBlock,
              ],
            )
          ],
        );
      },
    );
  }
}
